# Security Policy

## Supported Versions


| Version | Supported          |
| ------- | ------------------ |


## Reporting a Vulnerability

To report a vulnerability, please email academic_review_tool@outlook.com. 
We will reply to your email as soon as we are able and will provide a response to your report.
Accepted reports will be logged for immediate remediation.
